package com.company

import org.apache.commons.lang3.SystemUtils
import org.gradle.api.Plugin
import org.gradle.api.Project

class CPPBasePlugin implements Plugin<Project>{

	@Override
	public void apply(Project project) {

		project.with {

			apply plugin: 'cpp'

			model {

				buildTypes {
					debug
					release
				}
			}

			if(SystemUtils.IS_OS_WINDOWS) {
				
				project.task ('deployVisualStudio') {
					description 'Deploys Visual Studio.'
					doLast {
						// Implmentation omitted, since it is not required for reproducing the error.
						// It basicly downloads a visual studio distribution from artifactory an copies it to a specified destination.
					}
				}

				assemble.dependsOn('deployVisualStudio') // <-- THIS triggers the error (not happening in gradle 2.2.1).
				
				model {
					toolChains {
						// References Visual Studio Distribution deployed by task 'deployVisualStudio'.
						visualCpp(org.gradle.nativeplatform.toolchain.VisualCpp) {
							installDir file(visualStudioInstallDir) // <-- Adapt to local environment for testing (not essential for reproducing error).
							windowsSdkDir file(visualStudioWindowsSdkDir) // <-- Adapt to local environment for testing (not essential for reproducing error).
						}
					}

					platforms {
						win32 {
							architecture "x86"
							operatingSystem "windows"
						}
						win64 {
							architecture "x86_64"
							operatingSystem "windows"
						}
					}
				}
			}

			if(SystemUtils.IS_OS_LINUX) {

				model {
					toolChains {
						gcc(org.gradle.nativeplatform.toolchain.Gcc) { path '/usr/bin/' }
					}
					platforms {
						linux32 {
							architecture "x86"
							operatingSystem "linux"
						}
						linux64 {
							architecture "x86_64"
							operatingSystem "linux"
						}
					}
				}
			}
		}
	}
}
